EntityManager: Rename BasicVariantType to DBusValueVariant

Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
Change-Id: Ifde3020ee286ee6b98951df4bad5c3bd8d0251d2
diff --git a/src/Utils.cpp b/src/Utils.cpp
index 31a10bc..48c04fa 100644
--- a/src/Utils.cpp
+++ b/src/Utils.cpp
@@ -190,7 +190,7 @@
 std::optional<std::string> templateCharReplace(
     nlohmann::json::iterator& keyPair,
     const boost::container::flat_map<
-        std::string, boost::container::flat_map<std::string, BasicVariantType>>&
+        std::string, boost::container::flat_map<std::string, DBusValueVariant>>&
         allInterfaces,
     const size_t foundDeviceIdx, const std::optional<std::string>& replaceStr)
 {
@@ -211,7 +211,7 @@
 // ADDRESS field from a object on dbus
 std::optional<std::string> templateCharReplace(
     nlohmann::json::iterator& keyPair,
-    const boost::container::flat_map<std::string, BasicVariantType>&
+    const boost::container::flat_map<std::string, DBusValueVariant>&
         foundDevice,
     const size_t foundDeviceIdx, const std::optional<std::string>& replaceStr)
 {
@@ -456,7 +456,7 @@
 /// \brief JSON/DBus matching Callable for std::variant (visitor)
 ///
 /// Default match JSON/DBus match implementation
 /// \tparam T The concrete DBus value type from BasicVariantType
 template <typename T>
 struct MatchProbe
 {
@@ -517,7 +517,7 @@
     }
 };
 
-bool matchProbe(const nlohmann::json& probe, const BasicVariantType& dbusValue)
+bool matchProbe(const nlohmann::json& probe, const DBusValueVariant& dbusValue)
 {
     return std::visit(MatchProbeForwarder(probe), dbusValue);
 }
@@ -456,7 +456,7 @@
 ///
 /// Default match JSON/DBus match implementation
-/// \tparam T The concrete DBus value type from BasicVariantType
+/// \tparam T The concrete DBus value type from DBusValueVariant
 template <typename T>
 struct MatchProbe